==> deepin-font-manager_6.0.3.tar.xz: BUILD/translations/deepin-font-manager_ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Toles fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Fontes del sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Fontes del usuariu</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Fontes favorites</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Fontes actives</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Sinogrames</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Fontes monospaciaes</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 ye una familia de fontes. Si sigues, van desaniciase toles sos fontes</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 ye una familia de fontes. Si sigues, van activase toles sos fontes</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 ye una familia de fontes. Si sigues, van desactivase toles sos fontes</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desactivar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>El ficheru ta toyíu</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Instalóse la mesma versión</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte del sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Instalóse %1 fonte</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Instaláronse %1 fontes</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte nun va tar disponible pa les aplicaciones</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estes fontes nun van tar disponibles pa les aplicaciones</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La fonte «%1» ta n&apos;usu y nun pue desaniciase</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Desaniciando les fontes, espera…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificación de fontes</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nun va instalase nenguna fonte</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Siguir</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilu</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipu</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconozse</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completu</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Copyright</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Xestor de fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Deepin Font Manager ayuda a los usuarios a instalar y xestionar fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Cargando les fontes, espera…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>La fonte esportóse al escritoriu</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>Esportáronse %1 fontes al escritoriu</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Hebo un fallu al esportar 1 fonte. Nun hai abondu espaciu nel discu.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Hebo un fallu al esportar %1 fontes. Nun hai abondu espaciu nel discu.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Amestar fontes</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de Favoritos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivóse</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Desactiváronse les fontes</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 ta n&apos;usu polo que nun pues desactivar la fonte</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Nun pues desactivar les fontes del sistema y les que tán n&apos;usu</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Nun pues desactivar les fontes del sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconozse</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>El ficheru ta toyíu</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalóse</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nun s&apos;instaló</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nun hai resultaos</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nun hai fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar los atayos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Amestar fontes</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Teclexa pa previsualizar el testu</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_ast.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ast">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Toles fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Fontes del sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Fontes del usuariu</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Fontes favorites</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Fontes actives</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Sinogrames</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Fontes monospaciaes</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 ye una familia de fontes. Si sigues, van desaniciase toles sos fontes</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 ye una familia de fontes. Si sigues, van activase toles sos fontes</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 ye una familia de fontes. Si sigues, van desactivase toles sos fontes</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desactivar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>El ficheru ta toyíu</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Instalóse la mesma versión</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte del sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Instalóse %1 fonte</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Instaláronse %1 fontes</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">El ficheru ta toyíu</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte nun va tar disponible pa les aplicaciones</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estes fontes nun van tar disponibles pa les aplicaciones</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La fonte «%1» ta n&apos;usu y nun pue desaniciase</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Desaniciando les fontes, espera…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificación de fontes</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nun va instalase nenguna fonte</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Colar</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Siguir</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilu</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipu</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconozse</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completu</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Xestor de fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Deepin Font Manager ayuda a los usuarios a instalar y xestionar fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Cargando les fontes, espera…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>La fonte esportóse al escritoriu</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>Esportáronse %1 fontes al escritoriu</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Hebo un fallu al esportar 1 fonte. Nun hai abondu espaciu nel discu.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Hebo un fallu al esportar %1 fontes. Nun hai abondu espaciu nel discu.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Amestar fontes</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de Favoritos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desactivóse</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Desactiváronse les fontes</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 ta n&apos;usu polo que nun pues desactivar la fonte</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Nun pues desactivar les fontes del sistema y les que tán n&apos;usu</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Nun pues desactivar les fontes del sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconozse</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>El ficheru ta toyíu</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalóse</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nun s&apos;instaló</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nun hai resultaos</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nun hai fontes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar los atayos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Amestar fontes</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de favoritos</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Teclexa pa previsualizar el testu</translation>
    </message>
</context>
</TS>
